@@ -13,7 +13,9 @@ class ConfigManager:
         try:
             if os.path.exists(config_file):
                 with open(config_file, "r") as file:
-                    self.config = json.load(file)
+                    def transform_keys(obj):
+                        return {k.lower(): v for k, v in obj.items()}
+                    self.config = json.load(file, object_hook=transform_keys)
         except Exception as e:
             self.logger.log("Failed to load config from file", "error")
 
@@ -28,8 +30,8 @@ class ConfigManager:
     def get(self, key, default=None, value_type=None):
         # Use _get_config method to get the value. If None, return default.
         value = self._get_config(key)
-        if value_type and value_type == bool:
-            return self.parseBool(value or default)
+        if value is not None and value_type is not None and value_type == bool:
+            return self.parseBool(value)
         return value or default
 
     def validate_config(self):
@@ -59,3 +61,6 @@ class ConfigManager:
         for key in keys[:-1]:
             config = config.get(key, {})
         return config.get(keys[-1], None)
+
+    def __str__(self):
+        return json.dumps(self.config, indent=4, sort_keys=True)
