@@ -1,3 +1,7 @@
+import os
+import json
+import time
+
 from ..config import ConfigManager as Config
 from ..logger import Logger
 
@@ -5,11 +9,7 @@ from .report import QaseReport
 from .testops import QaseTestOps
 
 from ..models import Result, Attachment, Runtime
-from typing import Union
-
-import os
-import json
-import time
+from typing import Union, List
 
 """
     CoreReporter is a facade for all reporters and it is used to initialize and manage them.
@@ -21,13 +21,15 @@ class QaseCoreReporter:
     def __init__(self, config: Config):
         self.config = config
         self.logger = Logger(self.config.get('debug', False, bool))
-        self.execution_plan = None
+        self._execution_plan = None
         self.profilers = []
         self.overhead = 0
 
         self._selective_execution_setup()
         self.fallback = self._fallback_setup()
 
+        self.logger.log_debug(f"Config: {self.config}")
+
         # Reading reporter mode from config file
         mode = config.get("mode", "off")
 
@@ -48,7 +50,9 @@ class QaseCoreReporter:
         if self.reporter:
             try:
                 ts = time.time()
+                self.logger.log_debug("Starting run")
                 run_id = self.reporter.start_run()
+                self.logger.log_debug(f"Run ID: {run_id}")
                 self.overhead += time.time() - ts
                 return run_id
             except Exception as e:
@@ -56,11 +60,13 @@ class QaseCoreReporter:
                 self.logger.log(e, 'error')
                 self.reporter = None
 
-    def complete_run(self, exit_code=None) -> None:
+    def complete_run(self) -> None:
         if self.reporter:
             try:
                 ts = time.time()
-                self.reporter.complete_run(exit_code)
+                self.logger.log_debug("Completing run")
+                self.reporter.complete_run()
+                self.logger.log_debug("Run completed")
                 self.overhead += time.time() - ts
                 self.logger.log(f"Overhead for Qase Report: {round(self.overhead * 1000)}ms", 'info')
             except Exception as e:
@@ -72,7 +78,9 @@ class QaseCoreReporter:
         if self.reporter:
             try:
                 ts = time.time()
+                self.logger.log_debug(f"Adding result {result}")
                 self.reporter.add_result(result)
+                self.logger.log_debug(f"Result {result.get_title()} added")
                 self.overhead += time.time() - ts
             except Exception as e:
                 # Log error, disable reporting and continue
@@ -84,7 +92,9 @@ class QaseCoreReporter:
         if self.reporter:
             try:
                 ts = time.time()
+                self.logger.log_debug(f"Adding attachment {attachment}")
                 self.reporter.add_attachment(attachment)
+                self.logger.log_debug(f"Attachment {attachment.id} added")
                 self.overhead += time.time() - ts
             except Exception as e:
                 # Log error and run fallback
@@ -99,7 +109,8 @@ class QaseCoreReporter:
             if profiler == "network":
                 # Lazy import
                 from ..profilers import NetworkProfilerSingleton
-                NetworkProfilerSingleton.init(runtime=runtime)
+                NetworkProfilerSingleton.init(runtime=runtime,
+                                              skip_domain=self.config.get("testops.api.host", "qase.io"))
                 self.profilers.append(NetworkProfilerSingleton.get_instance())
             if profiler == "sleep":
                 from ..profilers import SleepProfiler
@@ -138,6 +149,9 @@ class QaseCoreReporter:
                 self.logger.log(e, 'error')
                 self._run_fallback()
 
+    def get_execution_plan(self) -> Union[List[int], None]:
+        return self._execution_plan
+
     def _run_fallback(self) -> None:
         if self.fallback:
             try:
@@ -163,7 +177,7 @@ class QaseCoreReporter:
                     api_token=self.config.get("testops.api.token"),
                     host=self.config.get("testops.api.host", "qase.io"),
                 )
-                self.execution_plan = loader.load(self.config.get("testops.project"),
+                self._execution_plan = loader.load(self.config.get("testops.project"),
                                                   int(self.config.get("testops.plan.id")))
         except Exception as e:
             self.logger.log('Failed to load test plan from Qase TestOps', 'info')
